@@ -5,7 +5,7 @@ use serde::{Deserialize, Serialize};
 #[cfg(feature = "non_critical_lints")]
 use crate::rules::non_critical_lints::{
     dot_notation::DotNotationConfig, eqeqeq::EqeqeqConfig, no_console::NoConsoleConfig,
-    no_use_before_define::NoUseBeforeDefineConfig,
+    no_restricted_syntax::NoRestrictedSyntaxConfig, no_use_before_define::NoUseBeforeDefineConfig,
     prefer_regex_literals::PreferRegexLiteralsConfig, quotes::QuotesConfig,
 };
 
@@ -23,15 +23,41 @@ impl Default for LintRuleReaction {
     }
 }
 
+#[derive(Debug, Clone, Copy, Serialize, Deserialize)]
+#[serde(untagged)]
+enum LintRuleLevel {
+    Str(LintRuleReaction),
+    Number(u8),
+}
+
+impl Default for LintRuleLevel {
+    fn default() -> Self {
+        Self::Str(LintRuleReaction::Off)
+    }
+}
+
+impl From<LintRuleLevel> for LintRuleReaction {
+    fn from(level: LintRuleLevel) -> Self {
+        match level {
+            LintRuleLevel::Str(level) => level,
+            LintRuleLevel::Number(level) => match level {
+                1 => LintRuleReaction::Warning,
+                2 => LintRuleReaction::Error,
+                _ => LintRuleReaction::Off,
+            },
+        }
+    }
+}
+
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct RuleConfig<T: Debug + Clone + Serialize + Default>(
-    #[serde(default)] LintRuleReaction,
+    #[serde(default)] LintRuleLevel,
     #[serde(default)] T,
 );
 
 impl<T: Debug + Clone + Serialize + Default> RuleConfig<T> {
-    pub(crate) fn get_rule_reaction(&self) -> &LintRuleReaction {
-        &self.0
+    pub(crate) fn get_rule_reaction(&self) -> LintRuleReaction {
+        self.0.into()
     }
 
     pub(crate) fn get_rule_config(&self) -> &T {
@@ -78,4 +104,12 @@ pub struct LintConfig {
     #[cfg(feature = "non_critical_lints")]
     #[serde(default)]
     pub eqeqeq: RuleConfig<EqeqeqConfig>,
+
+    #[cfg(feature = "non_critical_lints")]
+    #[serde(default, alias = "noNew")]
+    pub no_new: RuleConfig<()>,
+
+    #[cfg(feature = "non_critical_lints")]
+    #[serde(default, alias = "noRestrictedSyntax")]
+    pub no_restricted_syntax: RuleConfig<NoRestrictedSyntaxConfig>,
 }
